@@ -5,6 +5,7 @@ mod dict;
 mod file;
 mod frame;
 mod imgutils;
+mod mem;
 mod motion_vector;
 mod pixfmt;
 mod rational;
@@ -16,6 +17,7 @@ pub use dict::*;
 pub use file::*;
 pub use frame::*;
 pub use imgutils::*;
+pub use mem::*;
 pub use motion_vector::*;
 pub use pixfmt::*;
 pub use rational::*;
